<?php

// dołączenie plików funkcji tej aplikacji
require_once('funkcje_zakladki.php');
session_start();

// utworzenie zmiennych o krótkich nazwach
if (!isset($_POST['nazwa_uz']))  {
  //jeśli pole nie jest określone -> ustawiamy wartość zamienną
  $_POST['nazwa_uz'] = " "; 
}
$nazwa_uz = $_POST['nazwa_uz'];
if (!isset($_POST['haslo']))  {
  //jeśli pole nie jest określone -> ustawiamy wartość zamienną
  $_POST['haslo'] = " "; 
}
$haslo = $_POST['haslo'];

if ($nazwa_uz && $haslo) {
// właśnie nastąpiła próba logowania
  try {
    loguj($nazwa_uz, $haslo);
    // jeżeli użytkownik znajduje się w bazie danych, rejestracja identyfikatora
    $_SESSION['prawid_uzyt'] = $nazwa_uz;
  }
  catch (Exception $e) {
    // niepomyślne logowanie
    tworz_naglowek_html('Problem:');
    echo 'Zalogowanie niemożliwe.<br />
          Należy być zalogowanym, aby oglądać tę stronę.';
    tworz_HTML_URL('logowanie.php', 'Logowanie');
    tworz_stopke_html();
    exit;
  }
}

tworz_naglowek_html('Strona główna');
sprawdz_prawid_uzyt();
// odczytanie zakładek użytkownika
if ($tablica_url = pobierz_urle_uzyt($_SESSION['prawid_uzyt'])) {
  wyswietl_urle_uzyt($tablica_url);
}

// tworzenie menu opcji
wyswietl_menu_uzyt();

tworz_stopke_html();
?>
